@@ -50,6 +50,17 @@ class Embedding:
             item = tf.constant(item)
         ix = self.tf_vocabulary.lookup(item)
         return tf.gather(self.theta, ix, axis=0)
+
+    def __setitem__(self, item, new_value):
+        if type(item) == str:
+            item = [item]
+        if isinstance(item, list):
+            item = tf.constant(item)
+        ix = self.tf_vocabulary.lookup(item)
+        theta_new = self.theta.numpy()
+        ix = list(ix.numpy())
+        theta_new[list(ix)] = new_value
+        self.theta = tf.constant(theta_new)
     
     def __contains__(self, key):
         if type(key) == str:
